==> eiffelstudio-16.05.tar: F_code/C2/et82.c <==
/*
 * Code for class ET_ATTACHMENT_SCOPE_BUILDER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "et82.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ET_ATTACHMENT_SCOPE_BUILDER}.scope */
EIF_REFERENCE F142_1558 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {ET_ATTACHMENT_SCOPE_BUILDER}.build_scope */
void F142_1559 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_BOOLEAN loc1 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,arg2);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTGC;
	loc2 = *(EIF_REFERENCE *)(Current);
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg2;
	loc1 = *(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9164[Dtype(arg1)-1267])(RTCW(arg1), Current);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) loc1;
	RTAR(Current, loc2);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc2;
	RTLE;
}

/* {ET_ATTACHMENT_SCOPE_BUILDER}.build_negated_scope */
void F142_1560 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_BOOLEAN loc1 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,arg2);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTGC;
	loc2 = *(EIF_REFERENCE *)(Current);
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg2;
	loc1 = *(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9164[Dtype(arg1)-1267])(RTCW(arg1), Current);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) loc1;
	RTAR(Current, loc2);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc2;
	RTLE;
}

/* {ET_ATTACHMENT_SCOPE_BUILDER}.process_equality_expression */
void F142_1561 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc8 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc9 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc10 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc11 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc12 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(15);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,loc2);
	RTLR(5,loc3);
	RTLR(6,loc4);
	RTLR(7,loc5);
	RTLR(8,loc6);
	RTLR(9,loc7);
	RTLR(10,loc8);
	RTLR(11,loc9);
	RTLR(12,loc10);
	RTLR(13,loc11);
	RTLR(14,loc12);
	RTLIU(15);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_2_);
	tb1 = F1541_13964(RTCW(tr1));
	if ((EIF_BOOLEAN)(*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) == tb1)) {
		loc1 = *(EIF_REFERENCE *)(RTCW(arg1));
		loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R9394[Dtype(loc1)-1341])(RTCW(loc1));
		loc2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		loc2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R9394[Dtype(loc2)-1341])(RTCW(loc2));
		loc3 = loc2;
		loc3 = RTRV(eif_new_type(1559, 0x00),loc3);
		if (EIF_TEST(loc3)) {
			loc4 = loc1;
			loc4 = RTRV(eif_new_type(1563, 0x00),loc4);
			if (EIF_TEST(loc4)) {
				tr1 = *(EIF_REFERENCE *)(Current);
				loc5 = tr1;
				if (EIF_TEST(loc5)) {
					F978_8917(loc5);
				}
			} else {
				loc6 = loc1;
				loc6 = RTRV(eif_new_type(1599, 0x00),loc6);
				if (EIF_TEST(loc6)) {
					tr1 = *(EIF_REFERENCE *)(Current);
					loc7 = tr1;
					if (EIF_TEST(loc7)) {
						F978_8918(loc7, loc6);
					}
				}
			}
		} else {
			loc8 = loc1;
			loc8 = RTRV(eif_new_type(1559, 0x00),loc8);
			if (EIF_TEST(loc8)) {
				loc9 = loc2;
				loc9 = RTRV(eif_new_type(1563, 0x00),loc9);
				if (EIF_TEST(loc9)) {
					tr1 = *(EIF_REFERENCE *)(Current);
					loc10 = tr1;
					if (EIF_TEST(loc10)) {
						F978_8917(loc10);
					}
				} else {
					loc11 = loc2;
					loc11 = RTRV(eif_new_type(1599, 0x00),loc11);
					if (EIF_TEST(loc11)) {
						tr1 = *(EIF_REFERENCE *)(Current);
						loc12 = tr1;
						if (EIF_TEST(loc12)) {
							F978_8918(loc12, loc11);
						}
					}
				}
			}
		}
	}
	RTLE;
}

/* {ET_ATTACHMENT_SCOPE_BUILDER}.process_infix_expression */
void F142_1562 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,loc1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTGC;
	tb1 = *(EIF_BOOLEAN *)(RTCW(arg1)+ _CHROFF_3_0_);
	if (tb1) {
		loc1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_2_);
		if (*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_)) {
			tb1 = '\01';
			tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10112[Dtype(loc1)-1525])(RTCW(loc1));
			if (!tb2) {
				tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10113[Dtype(loc1)-1525])(RTCW(loc1));
				tb1 = tb2;
			}
			if (tb1) {
				tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
				(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9164[Dtype(tr1)-1267])(RTCW(tr1), Current);
				tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
				(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9164[Dtype(tr1)-1267])(RTCW(tr1), Current);
			} else {
				tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10107[Dtype(loc1)-1525])(RTCW(loc1));
				if (tb1) {
					*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_);
					tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
					(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9164[Dtype(tr1)-1267])(RTCW(tr1), Current);
					*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_);
					tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
					(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9164[Dtype(tr1)-1267])(RTCW(tr1), Current);
				}
			}
		} else {
			tb1 = '\01';
			tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10100[Dtype(loc1)-1525])(RTCW(loc1));
			if (!tb2) {
				tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10101[Dtype(loc1)-1525])(RTCW(loc1));
				tb1 = tb2;
			}
			if (tb1) {
				tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
				(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9164[Dtype(tr1)-1267])(RTCW(tr1), Current);
				tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
				(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9164[Dtype(tr1)-1267])(RTCW(tr1), Current);
			}
		}
	}
	RTLE;
}

/* {ET_ATTACHMENT_SCOPE_BUILDER}.process_named_object_test */
void F142_1563 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	F142_1564(Current, arg1);
}

/* {ET_ATTACHMENT_SCOPE_BUILDER}.process_object_test */
void F142_1564 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(8);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,loc3);
	RTLR(5,tr1);
	RTLR(6,loc4);
	RTLR(7,loc5);
	RTLIU(8);
	
	RTGC;
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_)) {
		loc1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_2_);
		loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R9394[Dtype(loc1)-1341])(RTCW(loc1));
		loc2 = loc1;
		loc2 = RTRV(eif_new_type(1563, 0x00),loc2);
		if (EIF_TEST(loc2)) {
			tr1 = *(EIF_REFERENCE *)(Current);
			loc3 = tr1;
			if (EIF_TEST(loc3)) {
				F978_8917(loc3);
			}
		} else {
			loc4 = loc1;
			loc4 = RTRV(eif_new_type(1599, 0x00),loc4);
			if (EIF_TEST(loc4)) {
				tr1 = *(EIF_REFERENCE *)(Current);
				loc5 = tr1;
				if (EIF_TEST(loc5)) {
					F978_8918(loc5, loc4);
				}
			}
		}
	}
	RTLE;
}

/* {ET_ATTACHMENT_SCOPE_BUILDER}.process_old_object_test */
void F142_1565 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	F142_1563(Current, arg1);
}

/* {ET_ATTACHMENT_SCOPE_BUILDER}.process_parenthesized_expression */
void F142_1566 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9164[Dtype(tr1)-1267])(RTCW(tr1), Current);
	RTLE;
}

/* {ET_ATTACHMENT_SCOPE_BUILDER}.process_prefix_expression */
void F142_1567 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	tb1 = *(EIF_BOOLEAN *)(RTCW(arg1)+ _CHROFF_2_0_);
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10123[Dtype(tr1)-1525])(RTCW(tr1));
		if (tb1) {
			*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_);
			tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9164[Dtype(tr1)-1267])(RTCW(tr1), Current);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_);
		}
	}
	RTLE;
}

void EIF_Minit82 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C2/et82.c <==
/*
 * Code for class ET_ATTACHMENT_SCOPE_BUILDER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "et82.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ET_ATTACHMENT_SCOPE_BUILDER}.build_scope */
void F137_1598 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_BOOLEAN loc1 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,arg2);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTGC;
	loc2 = *(EIF_REFERENCE *)(Current);
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg2;
	loc1 = *(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9585[Dtype(RTCW(arg1))-1299])(arg1, Current);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) loc1;
	RTAR(Current, loc2);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc2;
	RTLE;
}

/* {ET_ATTACHMENT_SCOPE_BUILDER}.build_negated_scope */
void F137_1599 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_BOOLEAN loc1 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,arg2);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTGC;
	loc2 = *(EIF_REFERENCE *)(Current);
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg2;
	loc1 = *(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9585[Dtype(RTCW(arg1))-1299])(arg1, Current);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) loc1;
	RTAR(Current, loc2);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc2;
	RTLE;
}

/* {ET_ATTACHMENT_SCOPE_BUILDER}.process_equality_expression */
void F137_1600 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc8 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc9 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc10 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc11 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc12 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(15);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,loc2);
	RTLR(5,loc3);
	RTLR(6,loc4);
	RTLR(7,loc5);
	RTLR(8,loc6);
	RTLR(9,loc7);
	RTLR(10,loc8);
	RTLR(11,loc9);
	RTLR(12,loc10);
	RTLR(13,loc11);
	RTLR(14,loc12);
	RTLIU(15);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_2_);
	tb1 = F1570_14440(RTCW(tr1));
	if ((EIF_BOOLEAN)(*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) == tb1)) {
		loc1 = *(EIF_REFERENCE *)(RTCW(arg1));
		loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R9791[Dtype(RTCW(loc1))-1351])(loc1);
		loc2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		loc2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R9791[Dtype(RTCW(loc2))-1351])(loc2);
		loc3 = loc2;
		loc3 = RTRV(eif_new_type(1581, 0x01),loc3);
		if (EIF_TEST(loc3)) {
			loc4 = loc1;
			loc4 = RTRV(eif_new_type(1583, 0x01),loc4);
			if (EIF_TEST(loc4)) {
				tr1 = *(EIF_REFERENCE *)(Current);
				loc5 = tr1;
				if (EIF_TEST(loc5)) {
					F1036_9555(loc5);
				}
			} else {
				loc6 = loc1;
				loc6 = RTRV(eif_new_type(1638, 0x01),loc6);
				if (EIF_TEST(loc6)) {
					tr1 = *(EIF_REFERENCE *)(Current);
					loc7 = tr1;
					if (EIF_TEST(loc7)) {
						F1036_9556(loc7, loc6);
					}
				}
			}
		} else {
			loc8 = loc1;
			loc8 = RTRV(eif_new_type(1581, 0x01),loc8);
			if (EIF_TEST(loc8)) {
				loc9 = loc2;
				loc9 = RTRV(eif_new_type(1583, 0x01),loc9);
				if (EIF_TEST(loc9)) {
					tr1 = *(EIF_REFERENCE *)(Current);
					loc10 = tr1;
					if (EIF_TEST(loc10)) {
						F1036_9555(loc10);
					}
				} else {
					loc11 = loc2;
					loc11 = RTRV(eif_new_type(1638, 0x01),loc11);
					if (EIF_TEST(loc11)) {
						tr1 = *(EIF_REFERENCE *)(Current);
						loc12 = tr1;
						if (EIF_TEST(loc12)) {
							F1036_9556(loc12, loc11);
						}
					}
				}
			}
		}
	}
	RTLE;
}

/* {ET_ATTACHMENT_SCOPE_BUILDER}.process_infix_expression */
void F137_1601 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,loc1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTGC;
	tb1 = *(EIF_BOOLEAN *)(RTCW(arg1)+ _CHROFF_3_0_);
	if (tb1) {
		loc1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_2_);
		if (*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_)) {
			tb1 = '\01';
			tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10905[Dtype(RTCW(loc1))-1594])(loc1);
			if (!tb2) {
				tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10906[Dtype(RTCW(loc1))-1594])(loc1);
				tb1 = tb2;
			}
			if (tb1) {
				tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
				(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9585[Dtype(RTCW(tr1))-1299])(tr1, Current);
				tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
				(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9585[Dtype(RTCW(tr1))-1299])(tr1, Current);
			} else {
				tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10900[Dtype(RTCW(loc1))-1594])(loc1);
				if (tb1) {
					*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_);
					tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
					(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9585[Dtype(RTCW(tr1))-1299])(tr1, Current);
					*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_);
					tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
					(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9585[Dtype(RTCW(tr1))-1299])(tr1, Current);
				}
			}
		} else {
			tb1 = '\01';
			tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10893[Dtype(RTCW(loc1))-1594])(loc1);
			if (!tb2) {
				tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10894[Dtype(RTCW(loc1))-1594])(loc1);
				tb1 = tb2;
			}
			if (tb1) {
				tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
				(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9585[Dtype(RTCW(tr1))-1299])(tr1, Current);
				tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
				(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9585[Dtype(RTCW(tr1))-1299])(tr1, Current);
			}
		}
	}
	RTLE;
}

/* {ET_ATTACHMENT_SCOPE_BUILDER}.process_named_object_test */
void F137_1602 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	F137_1603(Current, arg1);
}

/* {ET_ATTACHMENT_SCOPE_BUILDER}.process_object_test */
void F137_1603 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(8);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,loc3);
	RTLR(5,tr1);
	RTLR(6,loc4);
	RTLR(7,loc5);
	RTLIU(8);
	
	RTGC;
	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_)) {
		loc1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_2_);
		loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R9791[Dtype(RTCW(loc1))-1351])(loc1);
		loc2 = loc1;
		loc2 = RTRV(eif_new_type(1583, 0x01),loc2);
		if (EIF_TEST(loc2)) {
			tr1 = *(EIF_REFERENCE *)(Current);
			loc3 = tr1;
			if (EIF_TEST(loc3)) {
				F1036_9555(loc3);
			}
		} else {
			loc4 = loc1;
			loc4 = RTRV(eif_new_type(1638, 0x01),loc4);
			if (EIF_TEST(loc4)) {
				tr1 = *(EIF_REFERENCE *)(Current);
				loc5 = tr1;
				if (EIF_TEST(loc5)) {
					F1036_9556(loc5, loc4);
				}
			}
		}
	}
	RTLE;
}

/* {ET_ATTACHMENT_SCOPE_BUILDER}.process_old_object_test */
void F137_1604 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	F137_1602(Current, arg1);
}

/* {ET_ATTACHMENT_SCOPE_BUILDER}.process_parenthesized_expression */
void F137_1605 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9585[Dtype(RTCW(tr1))-1299])(tr1, Current);
	RTLE;
}

/* {ET_ATTACHMENT_SCOPE_BUILDER}.process_prefix_expression */
void F137_1606 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	tb1 = *(EIF_BOOLEAN *)(RTCW(arg1)+ _CHROFF_2_0_);
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10916[Dtype(RTCW(tr1))-1594])(tr1);
		if (tb1) {
			*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_);
			tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R9585[Dtype(RTCW(tr1))-1299])(tr1, Current);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_);
		}
	}
	RTLE;
}

void EIF_Minit82 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
